==> assert-is-hex-string-0.0.8.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# isHexString

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Test whether a string contains only hexadecimal digits.

<section class="installation">

## Installation

```bash
npm install @stdlib/assert-is-hex-string
```

</section>

<section class="usage">

## Usage

```javascript
var isHexString = require( '@stdlib/assert-is-hex-string' );
```

#### isHexString( value )

Tests whether a string contains only hexadecimal digits.

```javascript
var bool = isHexString( '0123456789abcdefABCDEF' );
// returns true
```

</section>

<!-- /.usage -->

<section class="notes">

## Notes

-   For non-string values, the function returns `false`.
-   The function does **not** recognize `x` (as in the standard `0x` prefix).

</section>

<!-- /.notes -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var isHexString = require( '@stdlib/assert-is-hex-string' );

var out = isHexString( '0123456789abcdefABCDEF' );
// returns true

out = isHexString( '' );
// returns false

out = isHexString( '0xffffff' );
// returns false

out = isHexString( 123 );
// returns false
```

</section>

<!-- /.examples -->

* * *

<section class="cli">

## CLI

<section class="installation">

## Installation

To use the module as a general utility, install the module globally

```bash
npm install -g @stdlib/assert-is-hex-string
```

</section>

<!-- CLI usage documentation. -->

<section class="usage">

### Usage

```text
Usage: is-hex-string [options] [<string>]

Options:

  -h,    --help                Print this message.
  -V,    --version             Print the package version.
```

</section>

<!-- /.usage -->

<section class="examples">

### Examples

```bash
$ is-hex-string 0123456789abcdefABCDEF
true
```

To use as a [standard stream][standard-streams],

```bash
$ echo -n '0123456789abcdefABCDEF' | is-hex-string
true
```

</section>

<!-- /.examples -->

</section>

<!-- /.cli -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

* * *

## See Also

-   <span class="package-name">[`@stdlib/assert/is-string`][@stdlib/assert/is-string]</span><span class="delimiter">: </span><span class="description">test if a value is a string.</span>

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2022. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/assert-is-hex-string.svg
[npm-url]: https://npmjs.org/package/@stdlib/assert-is-hex-string

[test-image]: https://github.com/stdlib-js/assert-is-hex-string/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/assert-is-hex-string/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/assert-is-hex-string/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/assert-is-hex-string?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/assert-is-hex-string.svg
[dependencies-url]: https://david-dm.org/stdlib-js/assert-is-hex-string/main

-->

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/assert-is-hex-string/tree/deno
[umd-url]: https://github.com/stdlib-js/assert-is-hex-string/tree/umd
[esm-url]: https://github.com/stdlib-js/assert-is-hex-string/tree/esm

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/assert-is-hex-string/main/LICENSE

[standard-streams]: https://en.wikipedia.org/wiki/Standard_streams

<!-- <related-links> -->

[@stdlib/assert/is-string]: https://www.npmjs.com/package/@stdlib/assert-is-string

<!-- </related-links> -->

</section>

<!-- /.links -->

==> assert-is-hex-string-0.0.9.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# isHexString

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Test whether a string contains only hexadecimal digits.

<section class="installation">

## Installation

```bash
npm install @stdlib/assert-is-hex-string
```

</section>

<section class="usage">

## Usage

```javascript
var isHexString = require( '@stdlib/assert-is-hex-string' );
```

#### isHexString( value )

Tests whether a string contains only hexadecimal digits.

```javascript
var bool = isHexString( '0123456789abcdefABCDEF' );
// returns true
```

</section>

<!-- /.usage -->

<section class="notes">

## Notes

-   For non-string values, the function returns `false`.
-   The function does **not** recognize `x` (as in the standard `0x` prefix).

</section>

<!-- /.notes -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var isHexString = require( '@stdlib/assert-is-hex-string' );

var out = isHexString( '0123456789abcdefABCDEF' );
// returns true

out = isHexString( '' );
// returns false

out = isHexString( '0xffffff' );
// returns false

out = isHexString( 123 );
// returns false
```

</section>

<!-- /.examples -->

* * *

<section class="cli">

## CLI

<section class="installation">

## Installation

To use the module as a general utility, install the module globally

```bash
npm install -g @stdlib/assert-is-hex-string
```

</section>

<!-- CLI usage documentation. -->

<section class="usage">

### Usage

```text
Usage: is-hex-string [options] [<string>]

Options:

  -h,    --help                Print this message.
  -V,    --version             Print the package version.
```

</section>

<!-- /.usage -->

<section class="examples">

### Examples

```bash
$ is-hex-string 0123456789abcdefABCDEF
true
```

To use as a [standard stream][standard-streams],

```bash
$ echo -n '0123456789abcdefABCDEF' | is-hex-string
true
```

</section>

<!-- /.examples -->

</section>

<!-- /.cli -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

* * *

## See Also

-   <span class="package-name">[`@stdlib/assert/is-string`][@stdlib/assert/is-string]</span><span class="delimiter">: </span><span class="description">test if a value is a string.</span>

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2022. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/assert-is-hex-string.svg
[npm-url]: https://npmjs.org/package/@stdlib/assert-is-hex-string

[test-image]: https://github.com/stdlib-js/assert-is-hex-string/actions/workflows/test.yml/badge.svg?branch=v0.0.9
[test-url]: https://github.com/stdlib-js/assert-is-hex-string/actions/workflows/test.yml?query=branch:v0.0.9

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/assert-is-hex-string/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/assert-is-hex-string?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/assert-is-hex-string.svg
[dependencies-url]: https://david-dm.org/stdlib-js/assert-is-hex-string/main

-->

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/assert-is-hex-string/tree/deno
[umd-url]: https://github.com/stdlib-js/assert-is-hex-string/tree/umd
[esm-url]: https://github.com/stdlib-js/assert-is-hex-string/tree/esm
[branches-url]: https://github.com/stdlib-js/assert-is-hex-string/blob/main/branches.md

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/assert-is-hex-string/main/LICENSE

[standard-streams]: https://en.wikipedia.org/wiki/Standard_streams

<!-- <related-links> -->

[@stdlib/assert/is-string]: https://www.npmjs.com/package/@stdlib/assert-is-string

<!-- </related-links> -->

</section>

<!-- /.links -->
